@@ -4,7 +4,7 @@ use strict;
 use Eixo::Base::Clase;
 
 
-our $VERSION = '0.2.5';
+our $VERSION = '0.3.1';
 
 has(
 
@@ -31,6 +31,11 @@ sub isInmediate{
 	$_[0]->isa('Eixo::QueueInmediate')
 }
 
+sub isDirect{
+
+	$_[0]->isa('Eixo::Queue::Direct');
+}
+
 1;
 
 
