@@ -30,11 +30,11 @@ sub addJob{
 
 
 	my $queue = $self->queues->{$job->queue};
-	
-	unless($queue->isInmediate){
+
+	unless($queue->isInmediate || $queue->isDirect){
 
 		#
-		# Add resolve unless inmediate queue
+		# Add resolve unless inmediate or direct queue 
 		#
 		$self->jobs_resolve->{$job->id} = $job->queue;
 	}
@@ -44,8 +44,9 @@ sub addJob{
 	#
 	$queue->add($job);
 
-	return $job->copy($queue->wait) if($queue->isInmediate);
+	return $job if($queue->isDirect);
 
+	return $job->copy($queue->wait) if($queue->isInmediate);
 
 	return 1;
 }
@@ -66,6 +67,10 @@ sub createQueue{
 
 	$self->queues->{$queue->name} = $queue;
 
+	open (D, '>>', '/tmp/debug') || die "$!";
+	print D "AQUI\n";
+	close D;
+
 	$queue->init;
 }
 
